<template>
    <div>
        <el-row type="flex" class="rowStyle">
            <el-col :xs="2" :sm="1" :class="{'state': agentInfo.new}"></el-col>
            <el-col :xs="22" :sm="23">
                <el-row type="flex">
                    <el-col class="flex_column" :xs="5" :sm="3">
                        <UiAvatar
                            :size="50"
                            :fileName="avatarFileName"
                            @click.native="showAgentDetail(agentInfo.agentNo)"
                        ></UiAvatar>
                        <div class="satisfaction">
                            <i class="icon-star pam-icon icon--yellow satisfaction"></i>
                            <span>{{agentInfo.avgScore }}</span>
                        </div>
                    </el-col>
                    <el-col :xs="10" :sm="15">
                        <div class="smTxt_bold name">{{agentInfo.name}}</div>
                        <div class="professionals">
                            <span
                                class="professionalsTxt"
                                v-for="(expertise, index) in expertises"
                                :key="index"
                            >#{{expertise}}</span>
                        </div>
                        <div
                            class="delete"
                            v-if="agentInfo.contactStatus === 'picked'
                                || !agentInfo.contactStatus"
                            @click="removeAgent"
                        >移除</div>
                    </el-col>
                    <el-col class="flex_column" :xs="9" :sm="6">
                        <el-button
                            class="smTxt_bold outline_btn"
                            @click="reserveCommunication"
                            :class="agentInfo.contactStatus + 'Btn'"
                        >{{ contactTxt }}</el-button>
                        <div class="updateTime" v-if="updateTime">{{updateTime | formatDate}}</div>
                    </el-col>
                </el-row>
            </el-col>
        </el-row>

        <Ui-Dialog
            :isVisible.sync="isVisibleDialog"
            :width="width"
            class="pam-myDemand-dialog"
        >
            <div v-if="appointmentDetail">
                <h5 class="subTitle text--center mb-30">預約成功</h5>
                <p class="smTxt">{{appointmentDetail.appointmentDate | formatDate}}</p>
                <div class="dialogInfo">
                    <p>姓名：{{appointmentDetail.name}}</p>
                    <p>電話：{{appointmentDetail.phone}}</p>
                    <p>Email：{{appointmentDetail.email}}</p>
                    <p>性別：{{gender}}</p>
                    <p>年齡：{{appointmentDetail.age | toAgeLabel }}</p>
                    <p>職業：{{appointmentDetail.job}}</p>
                    <p>需求：{{appointmentDetail.requirement.split(',').join('、')}}</p>
                    <p
                        v-for="(item, index) in hopeContactTime"
                        :key="index"
                    >連絡時段{{index + 1 | formatNumber}}：{{ item | formatHopeContactTime }}</p>
                </div>
            </div>
        </Ui-Dialog>
    </div>
</template>

<script lang="ts">
import { Vue, Component, Prop, Emit, Action } from 'nuxt-property-decorator';
import { Consultants, getAppointmentDetail } from '~/assets/ts/api/consultant';
import { AppointmentDetail } from '~/assets/ts/models/AppointmentDetail';
import { isLogin } from '~/assets/ts/auth';
import { isMobileDevice } from '~/assets/ts/device';

@Component({
    filters: {
        formatNumber(index: number) {
            if (index) {
                const upperNumber = ['零', '一', '二', '三', '四', '五', '六', '七', '八', '九', '十']
                return upperNumber[index];
            }
        },
        formatHopeContactTime(item: string): string {
          if (item) {
            const [hopeDay, hopeTime] = item.split('、');
            const day = hopeDay.split(',').length > 6 ? '不限日期' : hopeDay;
            const time = hopeTime.split(',').length > 3 ? '不限時間' : hopeTime;
            return `${day}、${time}`;
          }
          return '';
        }
    }
})
export default class ConsultantCard extends Vue {
    @Action removeFromMyConsultantList!: (agentNo: string) => Promise<boolean>;

    @Prop() agentInfo!: Consultants;
    isVisibleDialog = false;
    width: string = '';
    appointmentDetail: AppointmentDetail = {
        id: 0,
        phone: '',
        email: '',
        contactType: '',
        gender: '',
        age: '',
        job: '',
        requirement: '',
        communicateStatus: '',
        hopeContactTime: '',
        otherRequirement: '',
        appointmentDate: new Date(),
        agentNo: '',
        customerId: 0,
        name: ''
    };

    get avatarFileName() {
        return this.agentInfo.img ? this.agentInfo.img : this.agentInfo.image;
    }

    get expertises() {
        return this.agentInfo.expertise ? this.agentInfo.expertise : this.agentInfo.expertises;
    }
    get gender() {
        if (this.appointmentDetail.gender) {
            return this.appointmentDetail.gender === 'male' ? '男性' : '女性';
        }
        return ''
    }
    get contactTxt() {
        if (this.agentInfo.contactStatus === 'contacted') {
            return '已聯絡'
        }
        if (this.agentInfo.contactStatus === 'reserved') {
            return '已預約'
        }
        return '進行預約'
    }

    get updateTime() {
        return isLogin() ? this.agentInfo.updateTime : '';
    }

    get hopeContactTime() {
        const contactList = this.appointmentDetail.hopeContactTime
            .split("'").map(item => item.slice(0, item.length));
        return contactList.filter(item => !!item && item !== ",")
    }
    reserveCommunication() {
        const contactStatus = this.agentInfo.contactStatus;
        if (!contactStatus || contactStatus === 'picked') {
            isLogin()
                ? this.$router.push(`/questionnaire/${this.agentInfo.agentNo}`)
                : this.$router.push('/login');
        } else {
            this.openPopUp();
        }
    }

    openPopUp() {
        getAppointmentDetail(this.agentInfo.latestAppointmentId).then(res => {
            this.appointmentDetail = res.data;
            this.width = isMobileDevice() ? '80%' : '';
            this.isVisibleDialog = true;
        });
    }

    removeAgent() {
        this.removeFromMyConsultantList(this.agentInfo.agentNo).then((removeOk) => {
            console.log('removeOk?', removeOk);
        });
    }

    showAgentDetail(agentNo: string): void {
        this.$router.push(`/agentInfo/${agentNo}`);
    }
}
</script>

<style lang="scss" scoped>
    .rowStyle {
        padding: 10px;
        background-color: $PRIMARY_WHITE;
        margin-bottom: 10px;
        display: flex;
        justify-content: space-between;

        .state {
            width: 10px;
            height: 10px;
            border-radius: 50px;
            background-color: $YELLOW;
            margin: auto 0;
        }

        .satisfaction {
            font-size: 12px;
            font-weight: bold;
            margin-top: 5px;
        }

        .professionals {
            height: 20px;
            overflow: hidden;
            white-space: nowrap;
            text-overflow: ellipsis;
            margin: 5px 0 10px 0;

            .professionalsTxt {
                font-size: 12px;
                font-weight: bold;
                margin-right: 5px;
            }
        }

        .delete {
            color: $PRIMARY_RED;
            font-size: 14px;
            font-weight: bold;
            cursor: pointer;
        }

        .reservedBtn {
            color: $SKY_BLUE;
            border-color: $SKY_BLUE;

            &:focus {
                color: $PRIMARY_WHITE;
                background-color: $SKY_BLUE;
                opacity: 0.5;
            }
        }

        .contactedBtn {
            color: $GREEN;
            border-color: $GREEN;

            &:focus {
                color: $PRIMARY_WHITE;
                background-color: $GREEN;
                opacity: 0.5;
            }
        }

        .updateTime {
            font-size: 12px;
            font-weight: bold;
            color: #707070;
            text-align: right;
        }
    }

    .flex_column {
        display: flex;
        flex-direction: column;
        justify-content: space-between;
    }

    .dialogInfo {
        font-size: 20px;
        overflow-y:scroll;
        max-height: 50vh;
        @include desktop {
            height: 400px;
        }
    }

</style>
